# Author: Qi Li
# command
# python mBPIs.py -in <INPUT STATIC NETWORK> -dim <DESIRED FEATURE DIMENSION>
# example 
# python mBPIs.py -in ./Data/HPRD_Subnetworks/NetWalk-Static.txt -dim 30

import pandas as pd
import numpy as np
import networkx as nx
import sys 
import argparse
import os

##################################################
if not os.path.exists('./output/'):
	os.makedirs('./output/')


def parse_args():
	'''
	Parses arguments 
	'''

	parser = argparse.ArgumentParser(description="Run feature mBPIs")

	parser.add_argument("-in", "--input-network", dest='fn', type=str,
						help="Input network file")

	parser.add_argument("-dim", "--input-dimension", dest='m', type=int, default=30,
						help="Feature dimensions")

	return parser.parse_args()

def mBPIs(fn, m):
	netn = fn.split("/")[-1].split(".txt")[0]
	G = nx.read_edgelist(fn)
	node = list(G.nodes)

	## get the adjacency matrix for ethe network ###
	G_matrix = nx.to_numpy_matrix(G)
	G_matrix = pd.DataFrame(G_matrix)

	col = np.array(G_matrix.columns.tolist())
	freq = []
	for i in range(G_matrix.shape[1]):
		tmp = sum(G_matrix[i].tolist())
		freq.append(tmp)

	# check if tied case #
	rank = [sorted(freq, reverse=True).index(x)+1 for x in freq]
	rank = [x for x in rank if x <= m]
	m1 = len(rank)

	freq = np.array(freq)
	ind = list(freq.argsort()[::-1])
	ind = ind[:m1]
	col = col[ind]

	#print (col)

	Feature = G_matrix[col]
	
	Feature['ID'] = node
	col = Feature.columns.tolist()
	col = col[-1:] + col[:-1]

	Feature = Feature[col]

	Feature.to_csv('./output/' + str(m) + "BPIs_" + netn + ".txt", header = None, sep = '\t', index = False)



if __name__ == "__main__":

	args = parse_args()
	mBPIs(args.fn, args.m)



